<!--
SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>

SPDX-License-Identifier: GPL-3.0-or-later
-->

[![latest-docs](https://img.shields.io/badge/docs-v1.0.1-orange.svg)](https://credible.readthedocs.io/en/v1.0.1/)
[![build](https://gitlab.idiap.ch/biosignal/software/credible/badges/v1.0.1/pipeline.svg)](https://gitlab.idiap.ch/biosignal/software/credible/commits/v1.0.1)
[![coverage](https://gitlab.idiap.ch/biosignal/software/credible/badges/v1.0.1/coverage.svg)](https://www.idiap.ch/software/biosignal/docs/biosignal/software/credible/v1.0.1/coverage/index.html)
[![repository](https://img.shields.io/badge/gitlab-project-0000c0.svg)](https://gitlab.idiap.ch/biosignal/software/credible)

# Scikit-Learn compatible metrics with credible regions and confidence intervals

This library contains implementations of some scikit-learn metrics with credible regions and confidence intervals.

For installation and usage instructions, check-out our documentation.
